import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Form, Row, Col, Input, Icon, Select } from 'antd'

// import { formRule } from '@/utils/option.js'
import './index.scss'

class SettingForm extends Component {
  static propTpyes = {
    dict: PropTypes.object,        // 字典项
    tab: PropTypes.object,         // 数据源配置
    inputSubmit: PropTypes.func    // 回车事件
  }

  state = {roleList: []}

  UNSAFE_componentWillMount () {
    let roleList = sessionStorage.getItem('sysRoles')
    if (roleList) {
      try {
        roleList = JSON.parse(roleList)
      } catch {
        roleList = []
      }
    } else {
      roleList = []
    }

    this.setState({roleList})
  }

  handleConfirm = () => {
    // 表单提交时检查输入值是否正确
    return new Promise((resolve, reject) => {
      this.props.form.validateFieldsAndScroll((err, values) => {
        if (!err) {
          resolve(values)
        } else {
          reject(err)
        }
      })
    })
  }

  handleSubmit = (e) => {
    e.preventDefault()

    if (this.props.inputSubmit) {
      this.props.inputSubmit()
    }
  }

  render() {
    const { tab } = this.props
    const { getFieldDecorator } = this.props.form
    const { roleList } = this.state

    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 12 }
      }
    }

    return (
      <Form {...formItemLayout}>
        <Row gutter={24}>
          <Col span={24}>
            <Form.Item label="名称">
              {getFieldDecorator('label', {
                initialValue: tab.label,
                rules: [
                  {
                    required: true,
                    message: this.props.dict['form.required.input'] + '名称!'
                  }
                ]
              })(<Input placeholder={''} autoComplete="off" onPressEnter={this.handleSubmit} />)}
            </Form.Item>
          </Col>
          <Col span={24}>
            <Form.Item label="图标">
              {getFieldDecorator('icon', {
                initialValue: tab.icon || ''
              })(
                <Select>
                  <Select.Option key="empty" value=""> 无 </Select.Option>
                  <Select.Option key="android" value="android"> <Icon type="android" /> </Select.Option>
                  <Select.Option key="apple" value="apple"> <Icon type="apple" /> </Select.Option>
                  <Select.Option key="windows" value="windows"> <Icon type="windows" /> </Select.Option>
                  <Select.Option key="alipay" value="alipay"> <Icon type="alipay" /> </Select.Option>
                </Select>
              )}
            </Form.Item>
          </Col>
          <Col span={24}>
            <Form.Item label="黑名单">
              {getFieldDecorator('blacklist', {
                initialValue: tab.blacklist || []
              })(
                <Select
                  showSearch
                  mode="multiple"
                  filterOption={(input, option) => option.props.children.toLowerCase().indexOf(input.toLowerCase()) >= 0}
                >
                  {roleList.map(option =>
                    <Select.Option key={option.uuid} value={option.value}>{option.text}</Select.Option>
                  )}
                </Select>
              )}
            </Form.Item>
          </Col>
        </Row>
      </Form>
    )
  }
}

export default Form.create()(SettingForm)